@@ -350,7 +350,7 @@ class Extractor:
                 final_res["document_no_full"] += res.group(0)
                 number = res.group(1)
             else:
-                res = re.search('（([0-9]{6})）')
+                res = re.search('[（\(][0-9]{6}[\)）]', query)
                 if res:
                     final_res["document_no_full"] += res.group(0)
                     number = res.group(1)
